# The software in this package is distributed under the GNU General
# Public License version 2 (with a special exception described below).
#
# A copy of GNU General Public License (GPL) is included in this distribution,
# in the file COPYING.GPL.
#
# As a special exception, if other files instantiate templates or use macros
# or inline functions from this file, or you compile this file and link it
# with other works to produce a work based on this file, this file
# does not by itself cause the resulting work to be covered
# by the GNU General Public License.
#
# However the source code for this file must still be made available
# in accordance with section (3) of the GNU General Public License.
#
# This exception does not invalidate any other reasons why a work based
# on this file might be covered by the GNU General Public License.
#
# Copyright (c) 2016-2018 Intra2net AG <info@intra2net.com>

"""

SUMMARY
------------------------------------------------------
Utility for HTTP based interaction with the arnied web page.

Copyright: Intra2net AG


INTERFACE
------------------------------------------------------

"""

import re
import http.client as client
import urllib.parse as parse
import logging
log = logging.getLogger('web_interface')

from arnied_wrapper import accept_licence


def find_in_form(regex, form="status", escape=False):
    """
    Find a regex in I2N web page's status frame.

    :param str regex: regular expression to find
    :param bool escape: whether to escape the regex
    :returns: whether the regex was found
    :rtype: bool
    """
    accept_licence()
    data = web_page_request(method="GET", url="/arnie?form=" + form)
    if escape:
        regex = re.escape(regex)
    if re.search(regex, data):
        return True
    else:
        log.debug("'%s' could not be found in:\n%s", regex, data)
        return False


def web_page_request(method="GET", url="/", body=None):
    """
    Send an HTTPS request and return any response data.

    :param str method: GET or POST method for the request
    :param str url: url location within the remote host
    :param body: dictionary to be parsed and added to the url
    :type body: {str, str} or None
    :returns: data from the response if any
    :rtype: str
    """
    body = parse.urlencode(body) if body is not None else ""
    headers = {"Content-Type": "application/x-www-form-urlencoded",
               "Accept": "text/plain"}

    conn = client.HTTPSConnection("localhost")
    conn.request(method, url, body, headers)
    resp = conn.getresponse()
    logging.info("Request status %s and response %s",
                 resp.status, resp.reason)
    if resp.status != 200:
        raise exceptions.TestError("POST request failed.")
    data = resp.read().decode()
    conn.close()

    return data
